@@ -52,13 +52,7 @@ module CTioga2
       # A hook executed every time a dataset is pushed unto the stack
       # using #add_dataset.
       #
-      # \todo this string is parsed for each call to
-      # #add_dataset. Perhaps it would be good to provide a way to
-      # record a Command call, without parsing it from scratch ???
-      # 
-      # Although, with variables, that could be interesting to reparse
-      # everytime, since any change in the variables would be taken
-      # into account.
+      # This is a list of Instruction
       attr_accessor :dataset_hook
 
       # Creates a new DataStack object.
@@ -70,6 +64,8 @@ module CTioga2
         # Defaults to the 'text' backend
         @backend_factory = Data::Backends::BackendFactory.new('text')
 
+        @dataset_hook = []
+
         # Probably a bit out of place...
         csv = 
           Cmd.new('csv', nil, '--csv', []) do |plotmaker|
@@ -88,7 +84,7 @@ EOH
       # Performs expansion on the given _set_ with the current
       # backend, retrieves corresponding Dataset objects, pushes them
       # onto the stack and returns them.
-      def get_datasets(set, options = {})
+      def get_datasets(set, options = {}, add = true)
         backend = @backend_factory.specified_backend(options)
         sets = backend.expand_sets(set)
         datasets = []
@@ -100,7 +96,9 @@ EOH
             debug { "#{e.backtrace.join("\n")}" }
           end
         end
-        add_datasets(datasets, options)
+        if add
+          add_datasets(datasets, options)
+        end
         return datasets
       end
 
@@ -152,7 +150,16 @@ EOH
             end
           end
         else
-          if @named_datasets.key? spec
+          if spec =~ /^\s*#(.*)/
+            # graph idea -> get dataset from the plot element
+            eln = $1
+            obj = Elements::TiogaElement.find_object(eln)
+            if !obj.respond_to(:dataset)
+              raise "Object '##{eln}' does not name a plot"
+            end
+            ds = obj.dataset
+            index = @stack.index(ds)
+          elsif @named_datasets.key? spec
             name = spec
             ds = @named_datasets[spec]
             i = 0
@@ -189,13 +196,14 @@ EOH
       def store_dataset(dataset, ignore_hooks = false)
         @stack << dataset
         if @dataset_hook && (! ignore_hooks)
-          # \todo error handling
-          begin
-            PlotMaker.plotmaker.interpreter.run_commands(@dataset_hook)
-          rescue Exception => e
-            error { "There was a problem running the dataset hook '#{@dataset_hook}', disabling it" }
-            @dataset_hook = nil
-            info { "-> '#{format_exception e}'" }
+          for ins in @dataset_hook
+            begin
+              ins.run(PlotMaker.plotmaker)
+            rescue Exception => e
+              error { "There was a problem running the dataset hook '#{ins.to_s}', disabling it" }
+              @dataset_hook.delete(ins)
+              info { "-> '#{format_exception e}'" }
+            end
           end
         end
       end
@@ -222,9 +230,9 @@ EOH
       # Appends a set of commands to the dataset hook
       def add_to_dataset_hook(commands)
         if @dataset_hook
-          @dataset_hook << "\n#{commands}"
+          @dataset_hook += [commands].flatten
         else
-          @dataset_hook = commands
+          @dataset_hook = [commands].flatten
         end
       end
 
@@ -314,13 +322,34 @@ EOH
                    "Commands for manipulation of the data stack", 
                    100)
 
-    LoadDatasetOptions = { 
-      'name' => CmdArg.new('text'),
+    AppendDatasetOptions = { 
       'as' => CmdArg.new('text'),
       'where' => CmdArg.new('text'),
       'ignore_hooks' => CmdArg.new('boolean')
     }
     
+    AppendDataCommand = 
+      Cmd.new("append", nil, "--append", 
+              [ CmdArg.new('dataset'), ], 
+              AppendDatasetOptions) do |plotmaker, set, opts|
+      datasets = plotmaker.data_stack.get_datasets(set, opts, false)
+      # Now, we append them to the last dataset
+      plotmaker.data_stack.concatenate_datasets(datasets)
+    end
+    
+    AppendDataCommand.describe("Appends the datasets to the last in the stack",
+                             <<EOH, DataStackGroup)
+Use the current backend to load the given dataset(s) and append to the
+last dataset on the stack (without creating a new dataset). Roughly
+the equivalent of first running {command: load} and then 
+{command: join-datasets}.
+EOH
+    
+    LoadDatasetOptions = AppendDatasetOptions.dup.merge(
+      {
+        'name' => CmdArg.new('text')
+      })
+    
     LoadDataCommand = 
       Cmd.new("load", '-L', "--load", 
               [ CmdArg.new('dataset'), ], 
@@ -338,9 +367,10 @@ similar construct), each dataset gets named with %d replace with the
 number of the dataset within the expansion (starting at 0). This name
 can be used to further use the dataset without remembering its
 number. See the type {type: stored-dataset} for more information.
-
 EOH
 
+
+    
     ContourOptions = LoadDatasetOptions.dup.update({
       'which' => CmdArg.new('stored-dataset'),
     })
@@ -439,6 +469,57 @@ EOH
     ApplyLastCommand.describe("Applies a formula to the last dataset",
                               <<EOH, DataStackGroup)
 Applies a formula to the last dataset (or the named one)
+EOH
+
+    BinLastCommand = 
+      Cmd.new("bin", nil, "--bin", 
+              [], 
+              { 
+                'number' => CmdArg.new('integer'),
+                'column' => CmdArg.new('integer'),
+                'delta' => CmdArg.new('float'),
+                'min' => CmdArg.new('float'),
+                'max' => CmdArg.new('float'),
+                'normalize' => CmdArg.new('boolean'),
+                'which' => CmdArg.new('stored-dataset'),
+                'name' => CmdArg.new('text') 
+              }) do |plotmaker, opts|
+      stack = plotmaker.data_stack
+      ds = plotmaker.data_stack.specified_dataset(opts)
+
+      cn = opts['column'] || 1
+      col = ds.all_columns[cn]
+
+      
+      if opts.key? 'number'
+        min = opts['min'] || col.min
+        max = opts['max'] || col.max
+        number = opts['number']
+      elsif opts.key? 'delta'
+        delta = opts['delta']
+        if opts.key? 'min'
+          min = opts['min']
+          max = min+((col.max-min)/delta).ceil*delta
+        elsif opts.key? 'max'
+          max = opts['max']
+          min = max-((max-col.min)/delta).floor*delta
+        else
+          min = (col.min/delta).floor * delta
+          max = (col.max/delta).ceil * delta
+        end
+        number = ((max-min)/delta).to_i
+      else
+        raise "Must specify either the option 'number' or the option 'delta'"
+      end
+
+      newds = Dataset.new("bin", col.bin(min, max, number, opts['normalize']))
+      plotmaker.data_stack.add_datasets([newds], opts)
+    end
+    
+    BinLastCommand.describe("Bins the last dataset",
+                            <<EOH, DataStackGroup)
+This command bins the contents of the Y column of the last dataset on the 
+stack, and pushes the results as a new dataset.
 EOH
 
     ShowStackCommand = 
@@ -537,6 +618,7 @@ EOH
     SetDatasetHookCommand = 
       Cmd.new("dataset-hook", nil, "--dataset-hook", 
               [CmdArg.new('commands')], {}) do |plotmaker, commands, opts|
+      raise 'This command is disabled as of now'
       plotmaker.data_stack.dataset_hook = commands
     end
     
@@ -562,6 +644,7 @@ EOH
     AddDatasetHookCommand = 
       Cmd.new("dataset-hook-add", nil, "--dataset-hook-add", 
               [CmdArg.new('commands')], {}) do |plotmaker, commands, opts|
+      raise 'This command is disabled as of now'
       plotmaker.data_stack.add_to_dataset_hook(commands)
     end
     
