@@ -1,4 +1,4 @@
-# region.rb: draw curves-delimited fills
+# gradient-region.rb: draw neat color gradient
 # copyright (c) 2010 by Vincent Fourmond
   
 # This program is free software; you can redistribute it and/or modify
@@ -34,6 +34,8 @@ module CTioga2
         undef :elements
         undef :subframe
 
+        define_style "gradient"
+
         # The curves which delimit the region
         attr_accessor :curves
 
@@ -41,8 +43,9 @@ module CTioga2
         attr_accessor :start_color, :end_color
 
         # Creates a new empty region
-        def initialize(parent = nil, root = nil)
+        def initialize(parent, root, options)
           @parent = parent
+          setup_style(parent, options)
           
           # The curves whose color we should change
           @curves = []
