@@ -49,17 +49,23 @@ module CTioga2
         # @todo These are currently not implemented.
         attr_accessor :below, :above
 
-        # Whether the map follows RGB (true) or HLS (false). On by
-        # default.
+        # Whether the map is interpolated in the RGB (true) or HLS
+        # (false) color space. On by default.
         #
         # It does not change anything with respect to how the colors
         # are interpreted: whatever happens, the values are RGB.
         attr_accessor :rgb
 
+        # Whether or not the map should be considered symmetric around
+        # a given value.
+        attr_accessor :symmetry_center
+
         def initialize(values = [], colors = [])
           @values = values.dup
           @colors = colors.dup
 
+          @symmetry_center = nil
+
           @rgb = true
         end
         
@@ -77,12 +83,33 @@ module CTioga2
         def self.from_text(str)
           str = str.dup
           hls = false
-          re = /natural:?/i     # Not too bad ?
+          re = /(natural|hls|wheel):?/i     # Not too bad ?
           if str =~ re
             str.sub!(re,'')
             hls = true
           end
 
+          sym = nil
+
+          re = /:(?:sym|around):(.*)$/i
+          if str =~ re
+            sym = $1.to_f
+            str.sub!(re,'')
+          end
+
+          # We first try to see if it could be a color set ?
+          colorsettype = Commands::CommandType.get_type('color-set')
+
+          begin 
+            set = colorsettype.string_to_type(str)
+            cm = ColorMap.new([nil] * set.size, set)
+            cm.rgb = ! hls
+            cm.symmetry_center = sym
+            return cm
+          rescue Exception => e
+            # This is not a color set
+          end
+
           l = str.split(/::/)
           
 
@@ -141,6 +168,7 @@ module CTioga2
           cm.above = above
           cm.below = below
           cm.rgb = ! hls
+          cm.symmetry_center = sym
           return cm
         end
 
@@ -241,6 +269,19 @@ module CTioga2
         def z_values(zmin, zmax)
           # Real Z values.
           z_values = @values.dup
+
+          # We tweak the zmin and zmax to be symmetric around the
+          # symmetry_center should that be needed.
+          if @symmetry_center
+            dmin = (zmin - @symmetry_center).abs
+            dmax = (zmax - @symmetry_center).abs
+            
+            dfin = [dmin, dmax].max
+            zmin = @symmetry_center - dfin
+            zmax = @symmetry_center + dfin
+            
+          end
+
           z_values[0] ||= zmin
           z_values[-1] ||= zmax
 
@@ -252,10 +293,9 @@ module CTioga2
             if z_values[i]
               if last_value + 1 < i
                 (last_value+1).upto(i - 1) do |j|
-                  frac = (j - last_value)/(i - last_value + 1.0)
-                  # p [last_value, j, i, frac]
-                  z_values[j] = z_values[last_value] * frac + 
-                    z_values[i] * (1 - frac)
+                  frac = (j - last_value )/(i - last_value*1.0)
+                  z_values[j] = z_values[last_value] * (1 - frac) + 
+                    z_values[i] * frac
                 end
               end
               last_value = i
