@@ -31,7 +31,7 @@ module CTioga2
 
         OptionHashRE = /([\w-]+)\s*=\s*([^,]+),?\s*/
 
-        GridBoxRE = /^\s*grid:(\d+(?:-\d+)?)\s*,\s*(\d+(?:-\d+)?)(?:,(#{OptionHashRE}+))?\s*$/
+        GridBoxRE = /^\s*grid:(?:(\d+(?:-\d+)?)\s*,\s*(\d+(?:-\d+)?)|(next))(?:,(#{OptionHashRE}+))?\s*$/
 
         # This hash helps to convert from a hash-based representation
         # of frame coordinates to the array-based one.
@@ -44,11 +44,31 @@ module CTioga2
           'yb' => 3
         }
 
+        # The position of the element in the grid (arrays [left,right]
+        # or [top, bottom])
+        attr_accessor :x,:y
+
         def self.from_text(txt)
           if txt =~ GridBoxRE
-            return GridBox.new(GridLayout.current_grid, $1, $2, 
-                               $3) # The latter being to remove
-                                          # the initial comma
+            if $3               # next
+              x = 0
+              y = 0
+              grd = GridLayout.current_grid
+              lastel = grd.elements.last
+              if lastel
+                x = lastel.x.max + 1
+                y = lastel.y.max
+                if x >= grd.xsize
+                  x = 0
+                  y += 1
+                end
+              end
+              return GridBox.new(grd, x, y, $4)
+            else
+              return GridBox.new(GridLayout.current_grid, $1, $2, 
+                                 $4) # The latter being to remove
+            # the initial comma
+            end
           else
             raise "#{txt} is not a grid box."
           end
@@ -63,6 +83,19 @@ module CTioga2
             return [str.to_i, str.to_i]
           end
         end
+
+        # Returns false if the position given by @x and @y are within
+        # the grid
+        def within_grid?
+          if @x.min < 0 || @x.max >= @grid.xsize
+            return false
+          end
+          if @y.min < 0 || @y.max >= @grid.ysize
+            return false
+          end
+          return true
+        end
+          
         
         def initialize(grid, x, y, options = {})
           if options.is_a? String
@@ -83,6 +116,12 @@ module CTioga2
           @x = parse_range(x).sort
           @y = parse_range(y).sort
           @overrides = options || {}
+
+          if ! within_grid?
+            raise "Grid element #{x},#{y} is outside grid boundaries (#{@grid.xsize}x#{@grid.ysize})"
+          end
+
+          @grid.elements << self
         end
 
         def to_frame_coordinates(t)
@@ -99,6 +138,48 @@ module CTioga2
           end
           return a
         end
+
+        def classes
+          rv = []
+          hsh = {
+            'left' => @x.min == 0,
+            'right' => @x.max + 1 == @grid.xsize,
+            'top' => @y.min == 0,
+            'bottom' => @y.max + 1 == @grid.ysize
+          }
+          for k, v in hsh
+            if v
+              rv << "grid-#{k}"
+            else
+              rv << "grid-non-#{k}"
+            end
+          end
+
+          xv = nil
+          yv = nil
+          if @x.min == @x.max
+            xv = @x.min
+            rv << "grid-column-#{xv}"
+            if xv.even?
+              rv << "grid-even-column"
+            else
+              rv << "grid-odd-column"
+            end
+          end
+          if @y.min == @y.max
+            yv = @y.min
+            rv << "grid-row-#{yv}"
+            if yv.even?
+              rv << "grid-even-row"
+            else
+              rv << "grid-odd-row"
+            end
+          end
+          if xv && yv
+            rv << "grid-#{xv}-#{yv}"
+          end
+          return rv
+        end
       end
 
       # This class provides a grid-like layout through the use of a grid
@@ -125,6 +206,9 @@ module CTioga2
         # Vertical scales
         attr_accessor :vscales
 
+        # The GridBox objects we've seen so far
+        attr_accessor :elements
+
         def initialize(nup = "2x2")
           if nup.respond_to?(:split)
             if nup =~ /,/
@@ -156,6 +240,8 @@ module CTioga2
 
           @hscales ||= [1] * @nup[0]
           @vscales ||= [1] * @nup[1]
+
+          @elements = []
         end
 
         # The grid currently in use.
@@ -169,6 +255,14 @@ module CTioga2
           return @current_grid
         end
 
+        def xsize
+          return @hscales.size
+        end
+
+        def ysize
+          return @vscales.size
+        end
+
         # Compute the frame coordinates fo the x,y element of the
         # grid. They are numbered from the top,left element.
         def frame_coordinates(t, x, y)
