@@ -99,6 +99,9 @@
 # \todo make --xrange automatically select the range for the --math
 # backend unless another range was explicitly specified.
 
+# Maybe, maybe, maybe... We need tioga ?
+require 'Tioga/FigureMaker'
+
 require 'ctioga2/utils'
 require 'ctioga2/log'
 
@@ -109,8 +112,9 @@ require 'shellwords'
 # Path name mangling
 require 'pathname'
 
-# Maybe, maybe, maybe... We need tioga ?
-require 'Tioga/FigureMaker'
+# And yaml...
+require 'yaml'
+
 
 # Interaction with Ruby code
 require 'ctioga2/ruby'
@@ -279,6 +283,9 @@ module CTioga2
     end
 
     # ctioga's entry point.
+    #
+    # Returns true if there was no errors and false if there was one
+    # or more.
     def run(command_line)
 
       # The main catch-all around the plot:
@@ -311,6 +318,7 @@ module CTioga2
           STDIN.gets
         end
       end
+      return errs == 0
     end
 
     # Flushes the current root object and starts a new one:
@@ -490,8 +498,9 @@ module CTioga2
       # of ctioga2 used to produce the PDF, and the command-line if
       # applicable.
       t.tex_preamble += 
-        "\n\\pdfinfo {\n#{title}/Creator(#{Utils::pdftex_quote_string("ctioga2 #{Version::version}")})\n}\n"
+        "\n\\pdfinfo {\n#{title}/Creator(#{Utils::pdftex_quote_string("ctioga2 #{Version::version}")})\n}\n" 
 
+#" #emacs ruby-mode is a dummy
       return t
     end
 
@@ -530,6 +539,8 @@ EOH
     PlotLastOptions = 
       Graphics::Styles::CurveStyleFactory::PlotCommandOptions.dup
 
+    PlotLastOptions.merge!(Graphics::Elements::TiogaElement::StyleBaseOptions)
+
     PlotLastOptions['which'] = CmdArg.new('stored-dataset')
     
     PlotLastCommand = 
@@ -642,8 +653,7 @@ EOH
 
     ResolutionCommand = 
       Cmd.new("resolution", false,"--resolution", 
-              [ CmdArg.new('float') ],
-              ) do |plotmaker, size, options|
+              [ CmdArg.new('float') ]) do |plotmaker, size, options|
       plotmaker.pdf_resolution = size
     end
 
@@ -784,6 +794,19 @@ EOH
                         <<EOH, OutputSetupGroup)
 When this feature is on, all produced PDF files are converted to SVG
 using the neat pdf2svg program.
+EOH
+
+    CleanupPDFCommand = 
+      Cmd.new("cleanup-pdf",nil,"--cleanup-pdf", 
+              [CmdArg.new('boolean') ]) do |plotmaker,val|
+      plotmaker.postprocess.cleanup_pdf = val
+    end
+    
+    CleanupPDFCommand.describe('Cleanup produced PDF using gs', 
+                               <<EOH, OutputSetupGroup)
+If this is on, then @ctioga2@ uses ghostscript to cleanup the PDF file 
+produced. It is on by default is @ctioga2@ is able to find the @gs@ 
+executable.
 EOH
 
     EPSCommand = 
