@@ -64,6 +64,14 @@ module CTioga2
       return (flt.is_a?(Numeric) and flt.to_f.finite?)
     end
 
+    def self.nan_number?(flt)
+      return (flt.respond_to?(:nan?) and flt.nan?)
+    end
+
+    def self.infinite_number?(flt)
+      return (flt.respond_to?(:infinite?) and flt.infinite?)
+    end
+
     # Converts a number to a float while trying to stay as lenient as
     # possible
     def self.txt_to_float(txt)
@@ -199,6 +207,34 @@ module CTioga2
       return sets_by_prefix
     end
 
+    @@color_name_by_value = nil
+
+    def self.color_name_by_value_hsh
+      if ! @@color_name_by_value
+        @@color_name_by_value = {}
+        colors = Tioga::ColorConstants::constants
+        for c in colors
+          color = Tioga::ColorConstants::const_get(c)
+          @@color_name_by_value[Utils::color_to_html(color)] = c.to_s
+        end
+      end
+      return @@color_name_by_value
+    end
+
+    # Returns the Tioga name for the given color. Can be nil if the
+    # color does not match a Tioga named color.
+    def self.color_name_by_value(color)
+      return color_name_by_value_hsh()[Utils::color_to_html(color)]
+    end
+
+    # Transforms a Tioga color into a HTML color string "xxxxxx"
+    # (without the leeading #)
+    def self.color_to_html(color)
+      return color.map do |i|
+        "%02x" % (i*255.to_i)
+      end.join('')
+    end
+
     # An instrumentized version of Dir::chdir 
     def self.chdir(dir, &blk)
       @current_dirs ||= []
@@ -653,6 +689,15 @@ module CTioga2
 
 end
 
+
+# Patching YAML generation for recent Ruby
+
+class Dobjects::Dvector
+  def encode_with(coder)
+    coder.seq = self.to_a
+  end
+end
+
 ######################################################################
 # Now come a few functions that add to ruby's standard classes or
 # modules
