@@ -13,3 +13,6 @@ $ct --legend-inside br \
     '0.5*x' /color=hls:0.1,0.9,0.2 /legend='HLS fractions: hls:0.1,0.9,0.2' \
     '0.1*x' /color='#729!50!Green' /legend='xcolor mix: \#729!50!Green'
 
+$ct --math /samples=30 --marker auto --line-style no \
+    --marker-color-set Red\|Green\|Red\!30\|Green\!30 \
+    'x+1##8' x+12 /marker-color Red
