@@ -12,4 +12,13 @@ $ct --gradient Red Purple 'sin(x) + 0##11*0.1'
 $ct --gradient Red Purple \
     --legend-inside tc \
     --legend-line "Does legend work ?" \
-    'x**2 + 0##11*3'
\ No newline at end of file
+    'x**2 + 0##11*3'
+
+$ct --gradient Red Purple /id=gradient \
+    --legend-inside tc \
+    --legend-line "Reopening is fun" \
+    'x**2 + 0##5*3' \
+    --end \
+    'sin(x)' /color=Black \
+    --reopen gradient \
+    'x**2 + 6##11*3'
