@@ -17,5 +17,9 @@ $ct 'x**2' --inset 'cc:0.35' 'cos(x)'
 # Same thing with a range specification, just to check it works fine !
 $ct 'x**2' --inset 'cc:0.35' 'cos(x)' --yrange -2:2
 
+# This is not really an inset stuff, but...
+$ct --frame-margins 2mm /bottom=3dy /left=3cm 'x**2' 
+
+
 # $ct 'x**2' '1 - cos(x)' --zoom-inset 'cc:0.3' \
-#     --yrange -1:1 
\ No newline at end of file
+#     --yrange -1:1 
