@@ -21,3 +21,11 @@ $ct --margin 0.04 --region /color=Pink /reversed_color=Blue \
     /reversed_transparency 0.7 --math 'x' 'x+20'
 
 $ct --margin 0.04 'x' 'x+20' /id=stuff --hide stuff
+
+# More extreme hiding
+$ct --margin 0.04 'x' 'x+1'  /class=stuff 'x+2'  /class=stuff  \
+    'x+3'  /class=stf2 'x+4'  /class=stuff  'x+5'  /class=stf \
+    --hide .stuff
+
+$ct --margin 0.04 --legend-inside tl /id=lgd 'x' /legend=Legend \
+    --hide lgd
